@@ -1,4 +1,5 @@
 from pathlib import Path
+from .env import Env
 
 PROJECT_GITO_FOLDER = ".gito"
 PROJECT_CONFIG_FILE_NAME = "config.toml"
@@ -9,4 +10,5 @@ JSON_REPORT_FILE_NAME = "code-review-report.json"
 GITHUB_MD_REPORT_FILE_NAME = "code-review-report.md"
 EXECUTABLE = "gito"
 TEXT_ICON_URL = 'https://raw.githubusercontent.com/Nayjest/Gito/main/press-kit/logo/gito-bot-1_64top.png'  # noqa: E501
-HTML_TEXT_ICON = f'<a href="https://github.com/Nayjest/Gito"><img src="{TEXT_ICON_URL}" align="left" width=64 height=50 /></a>'  # noqa: E501
+HTML_TEXT_ICON = f'<a href="https://github.com/Nayjest/Gito"><img src="{TEXT_ICON_URL}" align="left" width=64 height=50 title="Gito v{Env.gito_version}"/></a>'  # noqa: E501
+HTML_CR_COMMENT_MARKER = '<!-- GITO_COMMENT:CODE_REVIEW_REPORT -->'
